# Moose Milestone（release/1.0）
- - - -
## 总体要求
* 时间上，要求在 _10月8号_ 之前完成版本1.0的编码和测试工作；
* 功能上：
	* 能对**automate**中95%的代码提供默认或仅需极少编码的实现；
	* 对重要但不在本次发布中提供的功能预留接口和说明；
* 质量上，整体代码覆盖率要提升到50%，频繁使用的功能需要提升覆盖率到85%以上；
* 维护上：
	* 提供 **command**，**actions**，**connection**的说明文档；
	* 对构成完整功能单元的模块（尤其对由单个文件构成的）提供头注释，说明该模块的主要设计目的，类提供功能和参数注释；
	* 在examples/中提供三个示例；

## 详细功能需求
详细功能需求上我们从三个方面说明，包括 **通用行为抽象**，**底层库和工具**和**交互**。

### 通用行为抽象
通用行为抽象是指对日常应用及功能进行抽象的结果，目的是对一组完整业务逻辑的编码复用，避免两套动作间因细微的差别而导致重复创造轮子的过程。在通用行为抽象层上，要求实现以下功能：
1. 上传
	1. 上传特定类型的所有数据到平台上1期任务，并生成索引；
	2. 根据文件夹上传到多期任务，并生成对应索引；
	3. 有选择地上传多种数据，但索引只根据其中某类数据生成；
2. 导出
	1. 自定义导出：提供task_id，自定义导出数据格式和所需处理；
	2. 标准化图像数据导出：导出原图，效果图，mask图和json文件；
	3. 标准化视频数据导出：导出每帧图片，效果图和csv文件；（提供标准命名方式）
	4. 标准化音频数据导出：导出单句音频，对应文本和metadata;（以多国模板为例）
	5. 图像json导出可以转化成PASCAL VOC格式；
	6. 提供图像导出metadata的入口；
3. 采转标（Migrate）
	1. 整期数据采集转标注；
	2. 提供号段和期数以及批次对照表转标注；（同时提供标准格式说明）
4. 语料制作（Assemble）
	1. 提供标准格式下语料制作接口； _（以children采转标为例）_
5. 预处理
	1. 视频抽帧
	2. 音频截断
6. 追责（Blame）
	1. 导出特定文件名下的标注人员的详细信息以及标注链接
7. 下载
	1. 定义标准下载接口，自动使用多线程完成数据下载

### 底层库和工具
底层库和工具为高层抽象行为的实现提供了支撑，同时也帮助开发人员在遇到通用行为抽象没有解决的问题的情况下快速进行实现。包括以下功能需要实现：
1. Azure云连接和常见操作：
	1. Azure云连接和重连；
	2. 批量/单个上传
	3. 批量/单个下载
	4. 列出容器内所有文件
	5. 创建容器
	6. 给容器修改权限
2. MongoDB数据库连接和常见操作：
	1. MongoDB连接和重连；
	2. MongoDB（条件）查询；
	3. MongoDB更新；
3. SQLServer数据库连接和常见操作；
	1. SQLServer连接和重连；
	2. SQLServer查询和批量查询；
	3. SQLServer插入和批量插入；
	4. SQLServer常用查询语句的定义； _（待详细定义）_
4. 数据提取过程
	1. 标准化标注数据提取过程：自由组合sql查询和mongodb提取过程获取结构化的原始和标注数据
	2. 标准化原始数据提取过程：未标注情况下，仅提取原始数据；
5. 工具箱（toolbox）
	1. 视频抽帧模块
	2. 图像绘制模块
	3. textgrid 解析模块
	4. ffmpeg调用模块
	5. 下载模块
	6. 标注结果检查模块
	7. 
6. Models
	1. 对通用格式建模
	2. 对GeoJSON格式建模
	3. 对app采集语音单段落数据建模
	4. 对语音多段落数据建模
	5. 对视频标注数据建模
	6. 提供基于model的异步下载
7. Utils
	1. 编码转换（gbk - unicode -utf-8）
	2. 系统路径转换（unix - windows）
	3. 常用函数的shortcuts _（带详细定义）_
		1. 路径遍历
		2. 文件夹检查和创建

### 交互
交互定义Moose和最终用户之间沟通的行为方式，是基于Moose的App完成之后对于输入和输出的格式的规范和说明，包括：
1. 按如下模式创建项目：
```shell
$ moose-admin startproject project_name
```

2. 按如下模式创建app：
```shell
$ cd project_name
$ python manage.py startapp app_name --template project_name/app_template
```

3. 按如下模式创建订单
```shell
$ python manage.py genconf app_name -c conf.cfg
```

4. 按如下模式编辑订单
```shell
$ python manage.py editconf app_name -c conf.cfg
```

5. 按如下模式使用指定订单运行动作
```shell
$ python manage.py run app_name -a act1 -a act2 -c conf1.cfg -c conf2.cfg -o opt1=val1
```
 

#moose
